/**
 * Copyright 2007-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.archive.api;

/**
 * Interface used by the Archive Manager to build implementation of EZBArchive.
 * @param <Type> the type supported by this factory.
 * @author Florent Benoit
 */
public interface IArchiveFactory<Type> {

    /**
     * Creates an EZBArchive object for the given object.
     * @param object the object that this factory can manage.
     * @return a new EZBArchive instance.
     */
    IArchive create(Type object);

    /**
     * @return the type supported by the factory
     */
    Class<Type> getSupportedClass();

}
